#ifndef MREADCT1ASCII_H
#define MREADCT1ASCII_H

#ifndef MTASK_H
#include "MTask.h"
#endif

class MNphotEvent ; 

class MReadCT1Ascii : public MTask
{
 private:
  TString fFileName;  //! the file name of the string

  FILE*   fInputfile ; //! the inputfile 

  MNphotEvent *fNphot ; //! the data container for all data. 

 public:
  MReadCT1Ascii(const char *filename, 
		const char *name=NULL, 
		const char *title=NULL);
  
  Bool_t PreProcess(MParList *pList);
  Bool_t Process();
  Bool_t PostProcess();
  
  ClassDef(MReadCT1Ascii, 1)	// Reads the CT1 data file
};
    
#endif
